# pymacaron-async

An extension of pymacaron seamlessly adding asynchronous task execution
based on celery/Redis.

See more at [pymacaron.com](http://pymacaron.com/async.html)

NOTE: tests for pymacaron-async are located in pymacaron-helloworld. This is temporary and needs to be fixed.
